==> openshift-model-5.12.3-sources.jar: io/fabric8/openshift/api/model/ImageListBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ImageListBuilder extends io.fabric8.openshift.api.model.ImageListFluentImpl<io.fabric8.openshift.api.model.ImageListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.ImageList,io.fabric8.openshift.api.model.ImageListBuilder>{
  public ImageListBuilder() {
    this(false);
  }
  public ImageListBuilder(java.lang.Boolean validationEnabled) {
    this(new ImageList(), validationEnabled);
  }
  public ImageListBuilder(io.fabric8.openshift.api.model.ImageListFluent<?> fluent) {
    this(fluent, false);
  }
  public ImageListBuilder(io.fabric8.openshift.api.model.ImageListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ImageList(), validationEnabled);
  }
  public ImageListBuilder(io.fabric8.openshift.api.model.ImageListFluent<?> fluent,io.fabric8.openshift.api.model.ImageList instance) {
    this(fluent, instance, false);
  }
  public ImageListBuilder(io.fabric8.openshift.api.model.ImageListFluent<?> fluent,io.fabric8.openshift.api.model.ImageList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ImageListBuilder(io.fabric8.openshift.api.model.ImageList instance) {
    this(instance,false);
  }
  public ImageListBuilder(io.fabric8.openshift.api.model.ImageList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.ImageListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.ImageList build() {
    ImageList buildable = new ImageList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ImageListBuilder that = (ImageListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-6.3.1-sources.jar: io/fabric8/openshift/api/model/ImageListBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ImageListBuilder extends ImageListFluentImpl<ImageListBuilder> implements VisitableBuilder<ImageList,ImageListBuilder>{
  public ImageListBuilder() {
    this(false);
  }
  public ImageListBuilder(Boolean validationEnabled) {
    this(new ImageList(), validationEnabled);
  }
  public ImageListBuilder(ImageListFluent<?> fluent) {
    this(fluent, false);
  }
  public ImageListBuilder(ImageListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ImageList(), validationEnabled);
  }
  public ImageListBuilder(ImageListFluent<?> fluent,ImageList instance) {
    this(fluent, instance, false);
  }
  public ImageListBuilder(ImageListFluent<?> fluent,ImageList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ImageListBuilder(ImageList instance) {
    this(instance,false);
  }
  public ImageListBuilder(ImageList instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ImageListFluent<?> fluent;
  Boolean validationEnabled;
  public ImageList build() {
    ImageList buildable = new ImageList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
